@@ -1,23 +1,23 @@
 context("maxLikelihood.ESF")
 
 test_that("maxLikelihood.ESF: use", {
-  skip_on_cran()
+ # skip_on_cran()
   set.seed(42)
   J <- 10000
   theta <- 100
   m <- 0.1
   I <- m * (J-1) / (1 - m)
-  
-  v <- generate.ESF(theta, I, J)  
+
+  v <- generate.ESF(theta, I, J)
   LL <- maxLikelihood.ESF(init_vals = c(100, 0.1),
-                          abund = c(v), verbose = FALSE)
+                          abund = c(v))
   m_est <- LL$par[2]
-  
-  expect_equal(m, 
-               m_est, 
+
+  expect_equal(m,
+               m_est,
                tolerance = 0.05)
-  expect_equal(theta, 
-               LL$par[1], 
+  expect_equal(theta,
+               LL$par[1],
                tolerance = 5)
 })
 
@@ -27,8 +27,8 @@ test_that("maxLikelihood.ESF: abuse", {
   theta <- 100
   m <- 0.1
   I <- m * (J-1) / (1 - m)
-  
-  v <- generate.ESF(theta, I, J)  
+
+  v <- generate.ESF(theta, I, J)
   expect_error(
     LL <- maxLikelihood.ESF(init_vals = c(-100, 0.1),
                             abund = v , verbose = FALSE),
@@ -44,7 +44,7 @@ test_that("maxLikelihood.ESF: abuse", {
                             abund = v, verbose = FALSE),
     "initial m can not be above 1"
   )
-  
+
   expect_error(
     LL <- maxLikelihood.ESF(init_vals = c(100, 0.1),
                             abund = c(1), verbose = FALSE),
